# Deploy AstrBot on CasaOS

## Install CasaOS

```bash
curl -fsSL https://get.casaos.io | sudo bash
```

## Add CasaOS-AppStore-Play App Store Source

![image](https://files.astrbot.app/docs/source/images/casaos/image.png)

Click `More Apps`, then enter:

```txt
https://play.cuse.eu.org/Cp0204-AppStore-Play.zip
```

And add it, wait for the addition to complete.

If your network environment is in mainland China, please search for and add `dkTurbo` first, otherwise you may not be able to pull the AstrBot image.

![image](https://files.astrbot.app/docs/source/images/casaos/image-1.png)

Enter `Astrbot` to find AstrBot.

![image](https://files.astrbot.app/docs/source/images/casaos/image-2.png)

Click the icon (not the install button), then hover over the `Install` button and click Custom Install.

![image](https://files.astrbot.app/docs/source/images/casaos/image-3.png)

In the Network section, select `host`.

![image](https://files.astrbot.app/docs/source/images/casaos/image-4.png)

Then click `Install` to start the installation.

After installation is complete, the AstrBot APP will appear on the main interface. Click it to open the dashboard.